@@ -93,7 +93,7 @@ class VersionsORM(Base):
 
 
 class KVStoreORM(Base):
-    """TODO: rename to """
+    """TODO: rename to"""
 
     __tablename__ = "kv_store"
 
@@ -152,7 +152,7 @@ class MoleculeORM(Base):
     provenance = Column(JSON)
     extras = Column(JSON)
 
-    __table_args__ = (Index("ix_molecule_hash", "molecule_hash", unique=True),)
+    __table_args__ = (Index("ix_molecule_hash", "molecule_hash", unique=False),)
 
 
 # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -300,7 +300,7 @@ class QueueManagerLogORM(Base):
 
 
 class QueueManagerORM(Base):
-    """"""
+    """ """
 
     __tablename__ = "queue_manager"
 
